message

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2020 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Message

type Message struct {
	Service string
	Buffer  string
	Target  string
	UUID    uint32
}

Message contains information about which file is being requested The UUID should be set to the client which is requesting the file

Jump to