Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Command ¶
type Command struct {
// The sending client ID
UUID uint32
CmdType CmdType
// Arguments for known commands, such as buffer/open/close/link
Args []string
// The active buffer of the client who sent the command
From string
}
Command is a ctl message
func FromString ¶
FromString retruns a command from string input, or an error if it was unable to parse
cmdChannel <- FromString(clientuuid, "buffer newbuffer") cmdChannel <- FromString(clientuuid, "link new old")
func New ¶
New - helper func with varargs If there are 2 args, the first is assumed to be the "From" path, the second "Args" If only one, it is set as "Args"
cmdChannel <- New(clientuuid, BufferCmd, "somebuffer", "newbuffer") cmdChannel <- New(clientuuid, CloseCmd, "somebuffer", "oldbuffer") cmdChannel <- New(clientuuid, LinkCmd, "oldbuffer", "newbuffer")
Click to show internal directories.
Click to hide internal directories.