Documentation
¶
Overview ¶
Package tabs contains helper functions for managing tabs in Altid services
go get github.com/altid/server/tabs
example
t, _ := tabs.FromFile("/path/to/a/service")
t.Remove("tab1")
tab := t.Add("tab2")
tab.SetState(Active|Alert)
fmt.Println("%s\n", tab)
Index ¶
Constants ¶
const ( Alert uint8 = 1 << iota Active ClearUnread )
Track the internal tab state
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manager ¶
Manager is used to manage tabs accurately for a service
Click to show internal directories.
Click to hide internal directories.